#
# spec file for package himalaya
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           himalaya
Version:        0.9.0~0
Release:        2.2
Summary:        Command-line interface for email management
License:        AGPL-3.0-only AND AGPL-3.0-or-later AND GPL-2.0-or-later AND MIT AND bzip2-1.0.6 AND MPL-2.0 AND CC-BY-3.0 AND BSD-4-Clause AND OpenSSL AND OFL-1.1
Group:          Productivity/Networking/Email/Clients
URL:            https://pimalaya.org/himalaya
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  libopenssl-devel
ExclusiveArch:  %{rust_tier1_arches}

%description
Command-line interface for email management.

%prep
%autosetup -a1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test}

%files
%{_bindir}/himalaya

%changelog
* Tue Sep 19 2023 Lubos Kocman <lubos.kocman@suse.com>
- Correction of license based on legaldb review
* Mon Sep  4 2023 Michael Vetter <mvetter@suse.com>
- Rewrite _service file to work around
  https://github.com/openSUSE/obs-service-tar_scm/issues/481
* Mon Aug 28 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.0:
  * Added 3 new cargo features:
    + pgp-commands: enables the commands PGP backend (enabled by default, same behaviour as before)
    + pgp-gpg: enables the GPG backend (requires the gpgme lib on the system)
    + pgp-native: enables the native PGP backend
  * Added account configuration pgp to configure the way PGP operations are performed.
  * Moved email-writing-encrypt-cmdto pgp.encrypt-cmd.
  * Moved email-reading-decrypt-cmd to pgp-decrypt-cmd.
  * Moved email-writing-sign-cmd to pgp.sign-cmd.
  * Moved email-reading-verify-cmd to pgp.verify-cmd.
* Tue Jul 18 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.8.4:
  * Fixed windows releases due to cargo deps typo.
* Tue Jul 18 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.8.3:
  * Fix windows releases due to coredump crate compilation error.
  * Fix macos releases due to macos 12 System Integrity Protection.
* Tue Jul 18 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.8.2:
  Changed:
  * Made the code async using the tokio async runtime.
  * On Linux, made the kernel keyring the default one (the one based on keyutils).
  Fixed:
  * Fixed the way folder aliases are resolved. In some case, aliases were
    resolved CLI side and lib side, which led to alias errors sourcehut#95.
* Fri Jun 23 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.8.1:
  Added:
  * Implemented OAuth 2.0 refresh token flow for IMAP and SMTP,
    which means that access tokens are now automatically refreshed
    and is transparent for users.
  * Added imap-oauth2-redirect-host and smtp-oauth2-redirect-host
    options to customize the redirect server host name (default: localhost).
  * Added imap-oauth2-redirect-port and smtp-oauth2-redirect-port
    options to customize the redirect server port (default: 9999).
  * Added email-listing-datetime-fmt to customize envelopes datetime
    format. See format spec here.
  * Added email-listing-local-datetime to transform envelopes datetime's
    timezone to the user's local one. For example, if the user's local
    is set to UTC, the envelope date 2023-06-15T09:00:00+02:00
    becomes 2023-06-15T07:00:00-00:00.
  Fixed:
  * Fixed missing < and > around Message-ID and In-Reply-To headers.
* Fri Jun  9 2023 Gus Kenion <gkenion@suse.com>
- Update to 0.8.0:
  Added:
  * Added keyring support, which means Himalaya can now use your system's global keyring to get/set sensitive data like passwords or tokens.
  * Added required IMAP option imap-auth and SMTP option smtp-auth. Possible values: passwd, oauth2.
  * Added OAuth 2.0 support for IMAP and SMTP.
  * Added passwords and OAuth 2.0 configuration via the wizard.
  * Added email-sending-save-copy option to control whenever a copy of any sent email should be saved in the sent folder defined in folder-aliases.
  * Imported id mapper from the lib, which means that the id mapping is now done by the CLI.
  * Added BackendConfig to AccountConfig::backend to match sender implementation.
  * Added support for pipeline commands, which means commands can be either a single command (string) or piped commands (list of strings). It applies for:
    + email-writing-verify-cmd
    + email-writing-decrypt-cmd
    + email-writing-sign-cmd
    + email-writing-encrypt-cmd
  Changed:
  * Changed release archive extensions from .tar.gz to .tgz.
  * Moved wizard module into domains (config, account, backend…).
  * [BREAKING] Changed the way secrets are managed. A secret is a sensitive data like passwords or tokens. There is 3 possible ways to declare a secret in the config file:
    + { raw = <secret> } for the raw secret as string (unsafe, not recommanded),
    + { cmd = <secret-cmd> } for command that exposes the secret,
    + { keyring = <secret-entry> } for entry in your system's global keyring that contains the secret.
    This applies for:
    + imap-passwd
    + imap-oauth2-client-secret
    + imap-oauth2-access-token
    + imap-oauth2-refresh-token
    + smtp-passwd
    + smtp-oauth2-client-secret
    + smtp-oauth2-access-token
    + smtp-oauth2-refresh-token
  Fixed:
  * Fixed Windows releases corrupted archives.
  Removed
  * [BREAKING] Removed -s|--sanitize option. It is done by default now, except if the -t|--mime-type html is set.
  * [BREAKING] Removed native-tls support, rustls-tls is now the only TLS provider available. Removed in consequence native-tls, rustls-tls and rustls-native-certs cargo features.
* Mon May  1 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.7.3:
  * Fixed Windows releases (due to typo in the github action script).
  * Fixed unit tests.
* Mon May  1 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.7.2:
  Added:
  * Added create and delete folder commands [sourcehut#54].
  * Added generated completions and man pages to releases
    [sourcehut#43].
  * Added new account config option sync-folders-strategy which allows
    to choose a folders synchronization strategy [sourcehut#59]:
    + sync-folders-strategy = "all": synchronize all existing folders
    for the current account
    + sync-folders-strategy.include = ["folder1", "folder2", …]:
    synchronize only the given folders for the current account
    + sync-folders-strategy.exclude = ["folder1", "folder2", …]:
    synchronizes all folders except the given ones for the current
    account
  * Also added new account sync arguments that override the account
    config option:
    + -A|--all-folders: include all folders to the synchronization.
    + -F|--include-folder: include given folders to the
    synchronization. They can be repeated -F folder1 folder2 or -F folder1 -F folder2.
    + -x|--exclude-folder: exclude given folders from the
    synchronization. They can be repeated -x folder1 folder2 or -x folder1 -F folder2.
  * Added cargo features native-tls (default), rustls-tls and
    rustls-native-certs.
  Changed:
  * Made global options truly global, which means they can be used
    everywhere (not only before commands but also after) [sourcehut#60].
  * Replaced reply all -a argument with -A because it conflicted
    with the global option -a|--account.
  * Replaced himalaya-lib by pimalaya-email.
  * Renamed feature vendored to native-tls-vendored.
  * Removed the develop branch, all the development is now done on the
    master branch.
  Fixed:
  * Fixed config deserialization issue with email-hooks and email-reading-format.
  * Fixed flags case sensitivity.
* Tue Feb 14 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.7.1:
  Added:
  * Added command folders expunge that deletes all emails marked for
    deletion.
  Changed:
  * Changed the location of the documentation.
  Fixed:
  * Fixed broken links in README.md.
  Removed:
  * Removed the maildir-backend cargo feature, it is now included by
    default.
  * Removed issues section on GitHub, now issues need to be opened by
    sending an email at ~soywod/pimalaya@todo.sr.ht.
* Wed Feb  8 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.7.0:
  Added:
  * Added offline support with the account sync command to synchronize
    a backend to a local Maildir backend [#342].
  * Added the flag --disable-cache to not use the local Maildir backend.
  * Added the email composer (from its own repository) [#341].
  * Added Musl builds to releases [#356].
  * Added himalaya man command to generate man page [#419].
  Changed:
  * Made commands read, attachments, flags, copy, move,
    delete accept multiple ids.
  * Flipped arguments ids and folder for commands copy and move
    in order the folder not to be considered as an id.
  Fixed:
  * Fixed missing folder aliases [#430].
  Removed:
  * Removed the -a|--attachment argument from write, reply and
    forward commands. Instead you can attach documents directly from
    the template using the syntax <#part filename=/path/to/you/document.ext>.
  * Removed the -e|--encrypt flag from write, reply and forward
    commands. Instead you can encrypt and sign parts directly from the
    template using the syntax <#part type=text/plain encrypt=command
    sign=command>Hello!<#/part>.
  * Removed the -l|--log-level option, use instead the RUST_LOG
    environment variable (see the wiki)
* Wed Oct 12 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.6.1:
  Added:
  * Added -s|--sanitize flag for the read command.
  Changed:
  * Changed the behaviour of the -t|--mime-type argument of the read
    command. It is less strict now: if no part is found for the given
    MIME type, it will fallback to the other one. For example, giving
  - t html will show in priority HTML parts, but if none of them are
    found it will show plain parts instead (and vice versa).
  * Sanitization is not done by default when using the read command,
    the flag -s|--sanitize needs to be explicitly provided.
  FixedL
  * Fixed empty text bodies when reading html part on plain text email
    [#352].
* Tue Oct 11 2022 Michael Vetter <mvetter@suse.com>
- Initial package of himalaya 0.6.0 for openSUSE
